# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: streamlit/proto/Markdown.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='streamlit/proto/Markdown.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1estreamlit/proto/Markdown.proto\"\xc8\x01\n\x08Markdown\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x12\x12\n\nallow_html\x18\x02 \x01(\x08\x12\x12\n\nis_caption\x18\x03 \x01(\x08\x12$\n\x0c\x65lement_type\x18\x04 \x01(\x0e\x32\x0e.Markdown.Type\x12\x0c\n\x04help\x18\x05 \x01(\t\"R\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06NATIVE\x10\x01\x12\x0b\n\x07\x43\x41PTION\x10\x02\x12\x08\n\x04\x43ODE\x10\x03\x12\t\n\x05LATEX\x10\x04\x12\x0b\n\x07\x44IVIDER\x10\x05\x62\x06proto3'
)



_MARKDOWN_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='Markdown.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NATIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAPTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CODE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LATEX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIVIDER', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=153,
  serialized_end=235,
)
_sym_db.RegisterEnumDescriptor(_MARKDOWN_TYPE)


_MARKDOWN = _descriptor.Descriptor(
  name='Markdown',
  full_name='Markdown',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='Markdown.body', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_html', full_name='Markdown.allow_html', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_caption', full_name='Markdown.is_caption', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element_type', full_name='Markdown.element_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='help', full_name='Markdown.help', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MARKDOWN_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=235,
)

_MARKDOWN.fields_by_name['element_type'].enum_type = _MARKDOWN_TYPE
_MARKDOWN_TYPE.containing_type = _MARKDOWN
DESCRIPTOR.message_types_by_name['Markdown'] = _MARKDOWN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Markdown = _reflection.GeneratedProtocolMessageType('Markdown', (_message.Message,), {
  'DESCRIPTOR' : _MARKDOWN,
  '__module__' : 'streamlit.proto.Markdown_pb2'
  # @@protoc_insertion_point(class_scope:Markdown)
  })
_sym_db.RegisterMessage(Markdown)


# @@protoc_insertion_point(module_scope)
