# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: streamlit/proto/PlotlyChart.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='streamlit/proto/PlotlyChart.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!streamlit/proto/PlotlyChart.proto\"x\n\x0bPlotlyChart\x12\r\n\x03url\x18\x01 \x01(\tH\x00\x12\x19\n\x06\x66igure\x18\x02 \x01(\x0b\x32\x07.FigureH\x00\x12\x1b\n\x13use_container_width\x18\x05 \x01(\x08\x12\r\n\x05theme\x18\x06 \x01(\tB\x07\n\x05\x63hartJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"&\n\x06\x46igure\x12\x0c\n\x04spec\x18\x01 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\tb\x06proto3'
)




_PLOTLYCHART = _descriptor.Descriptor(
  name='PlotlyChart',
  full_name='PlotlyChart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='PlotlyChart.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='figure', full_name='PlotlyChart.figure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_container_width', full_name='PlotlyChart.use_container_width', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theme', full_name='PlotlyChart.theme', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='chart', full_name='PlotlyChart.chart',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=37,
  serialized_end=157,
)


_FIGURE = _descriptor.Descriptor(
  name='Figure',
  full_name='Figure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec', full_name='Figure.spec', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Figure.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=197,
)

_PLOTLYCHART.fields_by_name['figure'].message_type = _FIGURE
_PLOTLYCHART.oneofs_by_name['chart'].fields.append(
  _PLOTLYCHART.fields_by_name['url'])
_PLOTLYCHART.fields_by_name['url'].containing_oneof = _PLOTLYCHART.oneofs_by_name['chart']
_PLOTLYCHART.oneofs_by_name['chart'].fields.append(
  _PLOTLYCHART.fields_by_name['figure'])
_PLOTLYCHART.fields_by_name['figure'].containing_oneof = _PLOTLYCHART.oneofs_by_name['chart']
DESCRIPTOR.message_types_by_name['PlotlyChart'] = _PLOTLYCHART
DESCRIPTOR.message_types_by_name['Figure'] = _FIGURE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PlotlyChart = _reflection.GeneratedProtocolMessageType('PlotlyChart', (_message.Message,), {
  'DESCRIPTOR' : _PLOTLYCHART,
  '__module__' : 'streamlit.proto.PlotlyChart_pb2'
  # @@protoc_insertion_point(class_scope:PlotlyChart)
  })
_sym_db.RegisterMessage(PlotlyChart)

Figure = _reflection.GeneratedProtocolMessageType('Figure', (_message.Message,), {
  'DESCRIPTOR' : _FIGURE,
  '__module__' : 'streamlit.proto.PlotlyChart_pb2'
  # @@protoc_insertion_point(class_scope:Figure)
  })
_sym_db.RegisterMessage(Figure)


# @@protoc_insertion_point(module_scope)
