"use strict";(self.webpackChunkstreamlit_browser=self.webpackChunkstreamlit_browser||[]).push([[467],{82467:function(e,r,n){n.r(r),n.d(r,{default:function(){return h}});var t=n(47313),o=n(83985),s=n(16168),i=n(50412),a=n(54922),l=n(47167),c=n(17208),u=n(81097),m=(0,l.Z)(c.Q,{shouldForwardProp:u.Z,target:"e17lx80j1"})((function(e){var r=e.theme,n=e.$usingCustomTheme;return{marginTop:r.spacing.none,marginBottom:r.spacing.none,marginRight:r.spacing.none,marginLeft:r.spacing.none,borderColor:r.colors.fadedText10,borderTopColor:n?r.colors.primary:r.colors.blue70,flexGrow:0,flexShrink:0}}),""),g=(0,l.Z)("div",{target:"e17lx80j0"})((function(e){return{display:"flex",gap:e.theme.spacing.lg,alignItems:"center",width:"100%"}}),""),d=n(46417);var h=function(e){var r=e.width,n=e.element,l=(0,o.u)(),c=t.useContext(a.I).activeTheme,u=!(0,s.MJ)(c),h={width:r};return(0,d.jsx)("div",{className:"stSpinner",style:h,children:(0,d.jsxs)(g,{children:[(0,d.jsx)(m,{$size:l.iconSizes.twoXL,$usingCustomTheme:u}),(0,d.jsx)(i.Z,{source:n.text,allowHTML:!1})]})})}}}]);