# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: streamlit/proto/LabelVisibilityMessage.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='streamlit/proto/LabelVisibilityMessage.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,streamlit/proto/LabelVisibilityMessage.proto\"\x99\x01\n\x16LabelVisibilityMessage\x12=\n\x05value\x18\x01 \x01(\x0e\x32..LabelVisibilityMessage.LabelVisibilityOptions\"@\n\x16LabelVisibilityOptions\x12\x0b\n\x07VISIBLE\x10\x00\x12\n\n\x06HIDDEN\x10\x01\x12\r\n\tCOLLAPSED\x10\x02\x62\x06proto3'
)



_LABELVISIBILITYMESSAGE_LABELVISIBILITYOPTIONS = _descriptor.EnumDescriptor(
  name='LabelVisibilityOptions',
  full_name='LabelVisibilityMessage.LabelVisibilityOptions',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VISIBLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIDDEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLLAPSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=138,
  serialized_end=202,
)
_sym_db.RegisterEnumDescriptor(_LABELVISIBILITYMESSAGE_LABELVISIBILITYOPTIONS)


_LABELVISIBILITYMESSAGE = _descriptor.Descriptor(
  name='LabelVisibilityMessage',
  full_name='LabelVisibilityMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='LabelVisibilityMessage.value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LABELVISIBILITYMESSAGE_LABELVISIBILITYOPTIONS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=202,
)

_LABELVISIBILITYMESSAGE.fields_by_name['value'].enum_type = _LABELVISIBILITYMESSAGE_LABELVISIBILITYOPTIONS
_LABELVISIBILITYMESSAGE_LABELVISIBILITYOPTIONS.containing_type = _LABELVISIBILITYMESSAGE
DESCRIPTOR.message_types_by_name['LabelVisibilityMessage'] = _LABELVISIBILITYMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LabelVisibilityMessage = _reflection.GeneratedProtocolMessageType('LabelVisibilityMessage', (_message.Message,), {
  'DESCRIPTOR' : _LABELVISIBILITYMESSAGE,
  '__module__' : 'streamlit.proto.LabelVisibilityMessage_pb2'
  # @@protoc_insertion_point(class_scope:LabelVisibilityMessage)
  })
_sym_db.RegisterMessage(LabelVisibilityMessage)


# @@protoc_insertion_point(module_scope)
