# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: streamlit/proto/GitInfo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='streamlit/proto/GitInfo.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dstreamlit/proto/GitInfo.proto\"\xd6\x01\n\x07GitInfo\x12\x12\n\nrepository\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\x12\x0e\n\x06module\x18\x03 \x01(\t\x12\x17\n\x0funtracked_files\x18\x04 \x03(\t\x12\x19\n\x11uncommitted_files\x18\x05 \x03(\t\x12!\n\x05state\x18\x06 \x01(\x0e\x32\x12.GitInfo.GitStates\"@\n\tGitStates\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x11\n\rHEAD_DETACHED\x10\x01\x12\x13\n\x0f\x41HEAD_OF_REMOTE\x10\x02\x62\x06proto3'
)



_GITINFO_GITSTATES = _descriptor.EnumDescriptor(
  name='GitStates',
  full_name='GitInfo.GitStates',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEAD_DETACHED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AHEAD_OF_REMOTE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=184,
  serialized_end=248,
)
_sym_db.RegisterEnumDescriptor(_GITINFO_GITSTATES)


_GITINFO = _descriptor.Descriptor(
  name='GitInfo',
  full_name='GitInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repository', full_name='GitInfo.repository', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch', full_name='GitInfo.branch', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module', full_name='GitInfo.module', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='untracked_files', full_name='GitInfo.untracked_files', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uncommitted_files', full_name='GitInfo.uncommitted_files', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='GitInfo.state', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GITINFO_GITSTATES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=248,
)

_GITINFO.fields_by_name['state'].enum_type = _GITINFO_GITSTATES
_GITINFO_GITSTATES.containing_type = _GITINFO
DESCRIPTOR.message_types_by_name['GitInfo'] = _GITINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GitInfo = _reflection.GeneratedProtocolMessageType('GitInfo', (_message.Message,), {
  'DESCRIPTOR' : _GITINFO,
  '__module__' : 'streamlit.proto.GitInfo_pb2'
  # @@protoc_insertion_point(class_scope:GitInfo)
  })
_sym_db.RegisterMessage(GitInfo)


# @@protoc_insertion_point(module_scope)
