(self.webpackChunkstreamlit_browser=self.webpackChunkstreamlit_browser||[]).push([[274],{12204:function(n,t,e){"use strict";e.d(t,{Z:function(){return f}});var r=e(47313),a=e(43575),i=e.n(a),o=e(46123),c=e.n(o),u=e(46417),s=function(n){var t=n.className,e=n.scriptRunId,r=n.numParticles,a=n.numParticleTypes,o=n.ParticleComponent;return(0,u.jsx)("div",{className:c()(t,"stHidden"),children:i()(r).map((function(n){var t=Math.floor(Math.random()*a);return(0,u.jsx)(o,{particleType:t},e+n)}))})},f=(0,r.memo)(s)},37066:function(n,t,e){"use strict";e.r(t),e.d(t,{NUM_FLAKES:function(){return v},default:function(){return y}});var r,a=e(47313),i=e.p+"static/media/flake-0.beded754e8024c73d9d2.png",o=e.p+"static/media/flake-1.8077dc154e0bf900aa73.png",c=e.p+"static/media/flake-2.e3f07d06933dd0e84c24.png",u=e(12204),s=e(30168),f=e(47167),p=e(30686),m=function(n){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:0;return Math.random()*(n-t)+t},l=(0,f.Z)("img",{target:"e1hbdfkw0"})((function(n){var t=n.theme;return{position:"fixed",top:"".concat(-150,"px"),marginLeft:"".concat(-75,"px"),zIndex:t.zIndices.balloons,left:"".concat(m(90,10),"vw"),animationDelay:"".concat(m(4e3),"ms"),height:"".concat(150,"px"),width:"".concat(150,"px"),pointerEvents:"none",animationDuration:"3000ms",animationName:(0,p.F4)(r||(r=(0,s.Z)(["\n  from {\n    transform:\n      translateY(0)\n      rotateX(","deg)\n      rotateY(","deg)\n      rotateZ(","deg);\n  }\n\n  to {\n    transform:\n      translateY(calc(100vh + ","px))\n      rotateX(0)\n      rotateY(0)\n      rotateZ(0);\n  }\n"])),m(360),m(360),m(360),150),animationTimingFunction:"ease-in",animationDirection:"normal",animationIterationCount:1,opacity:1}}),""),d=e(46417),v=100,x=[i,o,c],h=x.length,g=function(n){var t=n.particleType;return(0,d.jsx)(l,{src:x[t]})},b=function(n){var t=n.scriptRunId;return(0,d.jsx)(u.Z,{className:"snow",scriptRunId:t,numParticleTypes:h,numParticles:v,ParticleComponent:g})},y=(0,a.memo)(b)},2948:function(n){var t=Math.ceil,e=Math.max;n.exports=function(n,r,a,i){for(var o=-1,c=e(t((r-n)/(a||1)),0),u=Array(c);c--;)u[i?c:++o]=n,n+=a;return u}},2306:function(n,t,e){var r=e(5510),a=/^\s+/;n.exports=function(n){return n?n.slice(0,r(n)+1).replace(a,""):n}},53934:function(n,t,e){var r=e(2948),a=e(73271),i=e(89103);n.exports=function(n){return function(t,e,o){return o&&"number"!=typeof o&&a(t,e,o)&&(e=o=void 0),t=i(t),void 0===e?(e=t,t=0):e=i(e),o=void 0===o?t<e?1:-1:i(o),r(t,e,o,n)}}},5510:function(n){var t=/\s/;n.exports=function(n){for(var e=n.length;e--&&t.test(n.charAt(e)););return e}},43575:function(n,t,e){var r=e(53934)();n.exports=r},89103:function(n,t,e){var r=e(57923),a=1/0;n.exports=function(n){return n?(n=r(n))===a||n===-1/0?17976931348623157e292*(n<0?-1:1):n===n?n:0:0===n?n:0}},57923:function(n,t,e){var r=e(2306),a=e(91845),i=e(72060),o=/^[-+]0x[0-9a-f]+$/i,c=/^0b[01]+$/i,u=/^0o[0-7]+$/i,s=parseInt;n.exports=function(n){if("number"==typeof n)return n;if(i(n))return NaN;if(a(n)){var t="function"==typeof n.valueOf?n.valueOf():n;n=a(t)?t+"":t}if("string"!=typeof n)return 0===n?n:+n;n=r(n);var e=c.test(n);return e||u.test(n)?s(n.slice(2),e?2:8):o.test(n)?NaN:+n}}}]);