"use strict";(self.webpackChunkstreamlit_browser=self.webpackChunkstreamlit_browser||[]).push([[248],{80248:function(e,t,r){r.r(t),r.d(t,{default:function(){return n}});var u=r(47313),s=r(46417);function n(e){var t=e.element,r=e.width,n=e.endpoints,i=(0,u.useRef)(null);(0,u.useEffect)((function(){i.current&&(i.current.currentTime=t.startTime)}),[t.startTime]);var a=n.buildMediaURL(t.url);return(0,s.jsx)("audio",{id:"audio",ref:i,controls:!0,src:a,className:"stAudio",style:{width:r}})}}}]);