"use strict";(self.webpackChunkstreamlit_browser=self.webpackChunkstreamlit_browser||[]).push([[830],{10830:function(e,t,i){i.r(t),i.d(t,{default:function(){return s}});i(47313);var n=i(69367),r=i(50412),l=i(46417);var s=function(e){var t=e.disabled,i=e.element,s=e.widgetMgr,a=e.width,d=e.endpoints,u={width:a};return(0,l.jsx)("div",{className:"row-widget stDownloadButton",style:u,children:(0,l.jsx)(n.uD,{help:i.help,children:(0,l.jsx)(n.ZP,{kind:n.hY.SECONDARY,size:n.$u.SMALL,disabled:t,onClick:function(){s.setTriggerValue(i,{fromUi:!0});var e=document.createElement("a"),t="".concat(d.buildMediaURL(i.url),"?title=").concat(encodeURIComponent(document.title));e.setAttribute("href",t),e.setAttribute("target","_blank"),e.click()},fluidWidth:i.useContainerWidth||!1,children:(0,l.jsx)(r.Z,{source:i.label,allowHTML:!1,isLabel:!0,isButton:!0})})})})}}}]);