"use strict";(self.webpackChunkstreamlit_browser=self.webpackChunkstreamlit_browser||[]).push([[551],{94551:function(e,t,i){i.r(t),i.d(t,{default:function(){return n}});i(47313);var r=i(69367),s=i(50412),l=i(46417);var n=function(e){var t=e.disabled,i=e.element,n=e.widgetMgr,u={width:e.width},a="primary"===i.type?r.hY.PRIMARY:r.hY.SECONDARY;return(0,l.jsx)("div",{className:"row-widget stButton",style:u,children:(0,l.jsx)(r.uD,{help:i.help,children:(0,l.jsx)(r.ZP,{kind:a,size:r.$u.SMALL,disabled:t,fluidWidth:i.useContainerWidth||!1,onClick:function(){return n.setTriggerValue(i,{fromUi:!0})},children:(0,l.jsx)(s.Z,{source:i.label,allowHTML:!1,isLabel:!0,isButton:!0})})})})}}}]);