(self.webpackChunkstreamlit_browser=self.webpackChunkstreamlit_browser||[]).push([[705],{9441:function(t,i,e){"use strict";e.r(i),e.d(i,{default:function(){return h}});e(47313);var r,n=e(16390),a=e(26419),o=e(93986),d=e(47167),l=(0,d.Z)("div",{target:"etr89bj2"})((function(t){return{display:"flex",flexDirection:"row",flexWrap:"wrap",rowGap:t.theme.spacing.lg}}),""),s=(0,d.Z)("div",{target:"etr89bj1"})((function(){return{display:"flex",flexDirection:"column",alignItems:"stretch",width:"auto",flexGrow:0}}),""),c=(0,d.Z)("div",{target:"etr89bj0"})((function(t){var i=t.theme;return{fontFamily:i.genericFonts.bodyFont,fontSize:i.fontSizes.sm,color:i.colors.fadedText60,textAlign:"center",marginTop:i.spacing.xs,wordWrap:"break-word",padding:"0.125rem"}}),""),u=e(46417);!function(t){t[t.OriginalWidth=-1]="OriginalWidth",t[t.ColumnWidth=-2]="ColumnWidth",t[t.AutoWidth=-3]="AutoWidth"}(r||(r={}));var h=(0,a.Z)((function(t){var i,e=t.width,a=t.isFullScreen,d=t.element,h=t.height,f=t.endpoints,m=d.width;if(m===r.OriginalWidth||m===r.AutoWidth)i=void 0;else if(m===r.ColumnWidth)i=e;else{if(!(m>0))throw Error("Invalid image width: ".concat(m));i=m}var g={};return h&&a?(g.maxHeight=h,g["object-fit"]="contain"):(g.width=i,m===r.AutoWidth&&(g.maxWidth="100%")),(0,u.jsx)(l,{style:{width:e},children:d.imgs.map((function(t,i){var e=t;return(0,u.jsxs)(s,{"data-testid":"stImage",children:[e.markup?(0,n.ZP)((0,o.kB)(e.markup)):(0,u.jsx)("img",{style:g,src:f.buildMediaURL(e.url),alt:i.toString()}),e.caption&&(0,u.jsx)(c,{"data-testid":"caption",style:g,children:" ".concat(e.caption," ")})]},i)}))})}))},50247:function(){}}]);