(self.webpackChunkstreamlit_browser=self.webpackChunkstreamlit_browser||[]).push([[510],{13100:function(t,e,i){"use strict";i.r(e),i.d(e,{default:function(){return u}});var n=i(47313),r=i(2417),h=i(94178),a=i(72599),c=i(26419),o=(0,i(47167).Z)("div",{target:"e1p558ko0"})((function(t){return{"& *":{fontFamily:t.theme.genericFonts.bodyFont,fontSize:"9.6px"},"& svg":{maxWidth:"100%"}}}),""),s=i(46417);h.graphviz;var u=(0,c.Z)((function(t){var e=t.width,i=t.element,c=t.height,u="graphviz-chart-".concat(i.elementId),d=0,f=0,g=function(){var t=f,n=d;return c?(t=e,n=c):i.useContainerWidth&&(t=e),{chartWidth:t,chartHeight:n}},v=function(){try{var t=(0,h.graphviz)("#".concat(u)).zoom(!1).fit(!0).scale(1).renderDot(i.spec).on("end",(function(){var t=(0,r.Ys)("#".concat(u," > svg")).node();t&&(d=t.getBBox().height,f=t.getBBox().width)})),e=g(),n=e.chartHeight,c=e.chartWidth;n>0&&t.height(n),c>0&&t.width(c)}catch(o){(0,a.H)(o)}};(0,n.useEffect)((function(){v()}));var l=g(),p=l.chartWidth?l.chartWidth:e,m=l.chartHeight?l.chartHeight:c;return(0,s.jsx)(o,{className:"graphviz stGraphVizChart",id:u,style:{width:p,height:m}})}))},46825:function(){},35159:function(){},75701:function(){}}]);